pytest-xfaillist
===============

Maintain a xfaillist in an additional file to avoid merge-conflicts.

Develop
=======

We have to workaround the missing support of "install -e ." in poetry. To
develop please call:

```bash
./c/develop
```
